pub enum InternalError {
FailedToApplyFilter(String, String),
}Expand description
Errors that do not prohibit the Datadog grok algorithm from continuing processing.
Variants
FailedToApplyFilter(String, String)
When this error is encountered, the value associated with the filter is not parsed into the resulting object.