parse_grok

Function parse_grok 

pub fn parse_grok(
    source_field: &str,
    grok_rules: &[GrokRule],
) -> Result<ParsedGrokObject, FatalError>
Parses a given source field value by applying the list of grok rules until the first match found.